@@ -1,24 +1,16 @@
 package Email::Send::Sendmail;
-# $Id: Sendmail.pm,v 1.4 2005/05/11 03:01:26 cwest Exp $
+# $Id: Sendmail.pm,v 1.1 2004/05/28 02:18:16 cwest Exp $
 use strict;
 
-use Return::Value;
-
-use vars qw[$SENDMAIL];
-$SENDMAIL ||= q[sendmail];
-
-sub is_available {
-    return   `which $SENDMAIL`
-           ? success
-           : failure;
-}
+use vars qw[$VERSION $SENDMAIL];
+$VERSION  = (qw$Revision: 1.1 $)[1];
+$SENDMAIL = q[sendmail];
 
 sub send {
-    my ($class, $message, @args) = @_;
-    open SENDMAIL, "| $SENDMAIL -t -oi @args" or return failure;
+    my ($message, @args) = @_;
+    open SENDMAIL, "| $SENDMAIL -t -oi @args" or return undef;
     print SENDMAIL $message->as_string;
     close SENDMAIL;
-    return success;
 }
 
 1;
@@ -33,7 +25,7 @@ Email::Send::Sendmail - Send Messages using sendmail
 
   use Email::Send;
 
-  Email::Send->new({mailer => 'Sendmail'})->send($message);
+  send Sendmail => $message;
 
 =head1 DESCRIPTION
 
@@ -41,9 +33,9 @@ This mailer for C<Email::Send> uses C<sendmail> to send a message. It
 I<does not> try hard to find the executable. It just calls
 C<sendmail> and expects it to be in your path. If that's not the
 case, or you want to explicitly define the location of your executable,
-alter the C<$Email::Send::Sendmail::SENDMAIL> package variable.
+alter the C<$Email::Send::Qmail::SENDMAIL> package variable.
 
-  $Email::Send::Sendmail::SENDMAIL = '/usr/sbin/sendmail';
+  $Email::Send::Qmail::SENDMAIL = '/usr/sbin/sendmail';
 
 Any arguments passed to C<send> will be passed to C<sendmail>. The
 C<-t -oi> arguments are sent automatically.
